ReplaceDropImpl

Trait ReplaceDropImpl 

pub unsafe trait ReplaceDropImpl {
    // Required method
    unsafe fn drop(&mut self);
}
Safety

The implemenentor must ensure that they do not remove any drop functionality that is important When using ReplaceDrop, the struct’s fields to not automatically get dropped

Required Methods

unsafe fn drop(&mut self)

Safety

The caller must ensure this function is only called once

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ReplaceDropImpl for ()

Source

unsafe fn drop(&mut self)

Implementors