pub unsafe trait ReplaceDropImpl {
// Required method
unsafe fn drop(&mut self);
}Expand description
Safety
The implemenentor must ensure that they do not remove any drop functionality that is important When using ReplaceDrop, the struct’s fields to not automatically get dropped
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".